Package: germinationmetrics
Type: Package
Title: Seed Germination Indices and Curve Fitting
Version: 0.1.10
Authors@R: c(
    person(given = "J.", family = "Aravind",
           email = "j.aravind@icar.org.in",
           role = c("aut", "cre"),
		       comment = c(ORCID = "0000-0002-4791-442X")),
	  person(given = "S.", family = "Vimala Devi",
           email = "vimala.devi@icar.gov.in",
		       role = "aut"),
    person(given = "J.", family = "Radhamani",
           email = "jalli.radhamani@icar.gov.in",
		       role = "aut"),
	  person(given = c("Sherry", "Rachel"), family = "Jacob",
           email = "sherry.jacob@icar.org.in",
		       role = "aut"),
    person(given = c("Kalyani", "Srinivasan"),
           email = "kalyani.srinivasan@icar.gov.in",
		       role = "aut"),
    person("ICAR-NBGPR",
           role = "cph",
		       comment = c(url = "https://nbpgr.org.in/")))
Description: Provides functions to compute various germination indices
    such as germinability, median germination time, mean germination time,
    mean germination rate, speed of germination, Timson's index,
    germination value, coefficient of uniformity of germination,
    uncertainty of germination process, synchrony of germination etc. from
    germination count data. Includes functions for fitting cumulative seed
    germination curves using four-parameter hill function and computation
    of associated parameters. See the vignette for more, including full
    list of citations for the methods implemented.
License: GPL-2 | GPL-3
URL: https://github.com/aravind-j/germinationmetrics,
        https://aravind-j.github.io/germinationmetrics/
        https://CRAN.R-project.org/package=germinationmetrics
        https://doi.org/10.5281/zenodo.1219630
BugReports: https://github.com/aravind-j/germinationmetrics/issues
Depends: R (>= 3.5.0)
Imports: broom, cli, data.table, dplyr, ggplot2, ggrepel, gslnls,
        mathjaxr, methods, plyr, Rdpack, rlang, stats, utils
Suggests: httr, knitr, pander, curl, reshape2, rmarkdown, testthat (>=
        3.0.0), XML
VignetteBuilder: knitr
RdMacros: mathjaxr, Rdpack
Copyright: 2017-2026, ICAR-NBPGR
Encoding: UTF-8
LazyData: true
Config/testthat/edition: 3
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-21 11:05:25 UTC; Aravind-DGC
Author: J. Aravind [aut, cre] (ORCID: <https://orcid.org/0000-0002-4791-442X>),
  S. Vimala Devi [aut],
  J. Radhamani [aut],
  Sherry Rachel Jacob [aut],
  Kalyani Srinivasan [aut],
  ICAR-NBGPR [cph] (url: https://nbpgr.org.in/)
Maintainer: J. Aravind <j.aravind@icar.org.in>
Repository: CRAN
Date/Publication: 2026-04-21 22:22:21 UTC
Built: R 4.6.0; ; 2026-04-30 11:46:42 UTC; unix
