# Generated by roxygen2: do not edit by hand

S3method(plot,FourPHFfit)
S3method(plot,FourPHFfit.bulk)
export(CUGerm)
export(CVG)
export(CVGermTime)
export(EmergenceRateIndex)
export(FirstGermTime)
export(FourPHF)
export(FourPHF_fixa)
export(FourPHF_fixa_fixy0)
export(FourPHF_fixy0)
export(FourPHFfit)
export(FourPHFfit.bulk)
export(GeomLine2)
export(GeomPath2)
export(GermIndex)
export(GermPercent)
export(GermRateGeorge)
export(GermRateRecip)
export(GermSpeed)
export(GermSpeedAccumulated)
export(GermSpeedCorrected)
export(GermSynchrony)
export(GermUncertainty)
export(GermValue)
export(LastGermTime)
export(MeanGermNumber)
export(MeanGermPercent)
export(MeanGermRate)
export(MeanGermTime)
export(PeakGermPercent)
export(PeakGermTime)
export(PeakValue)
export(RateofGerm)
export(SEGermRate)
export(SEGermTime)
export(TimeSpreadGerm)
export(TimsonsIndex)
export(VarGermRate)
export(VarGermTime)
export(WeightGermPercent)
export(draw_key_path2)
export(geom_line2)
export(geom_path2)
export(germination.indices)
export(t50)
import(data.table)
import(ggplot2)
import(ggrepel)
import(gslnls)
import(mathjaxr)
importFrom(Rdpack,reprompt)
importFrom(broom,glance)
importFrom(broom,tidy)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(dplyr,bind_rows)
importFrom(grid,addGrob)
importFrom(grid,convertUnit)
importFrom(grid,gList)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,pointsGrob)
importFrom(grid,polylineGrob)
importFrom(grid,segmentsGrob)
importFrom(methods,is)
importFrom(plyr,mutate)
importFrom(plyr,round_any)
importFrom(rlang,`%||%`)
importFrom(rlang,list2)
importFrom(stats,ave)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,df)
importFrom(stats,integrate)
importFrom(stats,predict)
importFrom(utils,globalVariables)
importFrom(utils,tail)
